summaryrefslogtreecommitdiffstats
path: root/app/controllers/application_controller.rb
diff options
context:
space:
mode:
authorJean-Philippe Lang <jp_lang@yahoo.fr>2016-07-14 07:27:31 +0000
committerJean-Philippe Lang <jp_lang@yahoo.fr>2016-07-14 07:27:31 +0000
commitee82a55602a2178f9d5a978be3bf8492855d2c7f (patch)
tree66f37b39f91217e64ef2e40bbdc96a4e574c7ad2 /app/controllers/application_controller.rb
parentd2f7e31951d0e150df9cfd6da7d91d855f734d5f (diff)
downloadredmine-ee82a55602a2178f9d5a978be3bf8492855d2c7f.tar.gz
redmine-ee82a55602a2178f9d5a978be3bf8492855d2c7f.zip
Use .before_action instead of .before_filter.
git-svn-id: http://svn.redmine.org/redmine/trunk@15655 e93f8b46-1217-0410-a6f0-8f06a7374b81
Diffstat (limited to 'app/controllers/application_controller.rb')
-rw-r--r--app/controllers/application_controller.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/app/controllers/application_controller.rb b/app/controllers/application_controller.rb
index f998be775..6768d1647 100644
--- a/app/controllers/application_controller.rb
+++ b/app/controllers/application_controller.rb
@@ -51,7 +51,7 @@ class ApplicationController < ActionController::Base
end
end
- before_filter :session_expiration, :user_setup, :check_if_login_required, :check_password_change, :set_localization
+ before_action :session_expiration, :user_setup, :check_if_login_required, :check_password_change, :set_localization
rescue_from ::Unauthorized, :with => :deny_access
rescue_from ::ActionView::MissingTemplate, :with => :missing_template
@@ -369,7 +369,7 @@ class ApplicationController < ActionController::Base
end
# make sure that the user is a member of the project (or admin) if project is private
# used as a before_filter for actions that do not require any particular permission on the project
def check_project_privacy
if @project && !@project.archived?
if @project.visible?
@@ -369,7 +369,7 @@ class ApplicationController < ActionController::Base
end
# make sure that the user is a member of the project (or admin) if project is private
- # used as a before_filter for actions that do not require any particular permission on the project
+ # used as a before_action for actions that do not require any particular permission on the project
def check_project_privacy
if @project && !@project.archived?